@@ -1,8 +1,8 @@
 """Implement a base class for API."""
 
 import dataclasses as dc
-import typing as t
 from pathlib import Path
+from typing import Any, Awaitable, Callable, Dict, List, Optional, TypeVar, Union
 
 import muffin
 from http_router import Router
@@ -10,28 +10,36 @@ from muffin.utils import to_awaitable
 
 from .openapi import render_openapi
 
-
-AUTH = t.TypeVar('AUTH', bound=t.Callable[[muffin.Request], t.Awaitable])
-REDOC_TEMPLATE = Path(__file__).parent.joinpath('redoc.html').read_text()
-SWAGGER_TEMPLATE = Path(__file__).parent.joinpath('swagger.html').read_text()
+AUTH = TypeVar("AUTH", bound=Callable[[muffin.Request], Awaitable])
+REDOC_TEMPLATE = Path(__file__).parent.joinpath("redoc.html").read_text()
+SWAGGER_TEMPLATE = Path(__file__).parent.joinpath("swagger.html").read_text()
 
 
 @dc.dataclass
 class API:
     """Initialize an API."""
 
-    def __init__(self, app: muffin.Application = None, prefix: str = '',
-                 openapi: bool = True, *, servers: t.List = None, **openapi_info):
+    def __init__(
+        self,
+        app: Optional[muffin.Application] = None,
+        prefix: str = "",
+        openapi: bool = True,
+        *,
+        servers: Optional[List] = None,
+        **openapi_info,
+    ):
         """Post initialize the API if we have an application already."""
         self.app = app
         self.prefix = prefix
 
         self.openapi = openapi
-        self.openapi_options: t.Dict[str, t.Any] = {'info': openapi_info}
+        self.openapi_options: Dict[str, Any] = {"info": openapi_info}
         if servers:
-            self.openapi_options['servers'] = servers
+            self.openapi_options["servers"] = servers
 
-        self.authorize: t.Callable[[muffin.Request], t.Awaitable] = to_awaitable(lambda _: True)
+        self.authorize: Callable[[muffin.Request], Awaitable] = to_awaitable(
+            lambda _: True
+        )
         self.router = Router()
 
         if app:
@@ -50,29 +58,36 @@ class API:
     def logger(self):
         """Proxy the application's logger."""
         if self.app is None:
-            raise RuntimeError('API must be binded to an app.')
+            raise RuntimeError("API must be binded to an app.")
 
         return self.app.logger
 
-    def setup(self, app: muffin.Application, prefix: str = '',
-              openapi: bool = None, *, servers: t.List = None, **openapi_info):
+    def setup(
+        self,
+        app: muffin.Application,
+        prefix: str = "",
+        openapi: Optional[bool] = None,
+        *,
+        servers: Optional[List] = None,
+        **openapi_info,
+    ):
         """Initialize the API."""
         self.app = app
-        self.prefix = (prefix or self.prefix).rstrip('/')
+        self.prefix = (prefix or self.prefix).rstrip("/")
 
         # Setup routing
         self.router.trim_last_slash = self.app.router.trim_last_slash
-        self.router.validator = self.app.router.validator                   # type: ignore
+        self.router.validator = self.app.router.validator
         self.app.router.route(self.prefix)(self.router)
 
         if openapi is not None:
             self.openapi = openapi
 
         if openapi_info:
-            self.openapi_options['info'] = openapi_info
+            self.openapi_options["info"] = openapi_info
 
         if servers:
-            self.openapi_options['servers'] = servers
+            self.openapi_options["servers"] = servers
 
         # Setup API Docs
         if not self.openapi:
@@ -81,11 +96,11 @@ class API:
         async def openapi_json(request):
             return render_openapi(self, request=request)
 
-        self.router.route('/swagger')(swagger)
-        self.router.route('/redoc')(redoc)
-        self.router.route('/openapi.json')(openapi_json)
+        self.router.route("/swagger")(swagger)
+        self.router.route("/redoc")(redoc)
+        self.router.route("/openapi.json")(openapi_json)
 
-    def route(self, path: t.Union[str, t.Any], *paths: str, **params):
+    def route(self, path: Union[str, Any], *paths: str, **params):
         """Route an endpoint by the API."""
         from .handler import RESTBase
 
@@ -106,8 +121,10 @@ class API:
 
 
 async def swagger(_):
+    """Get the Swagger UI."""
     return SWAGGER_TEMPLATE
 
 
 async def redoc(_):
+    """Get the ReDoc UI."""
     return REDOC_TEMPLATE
