@@ -1,12 +1,15 @@
 """Base class for API REST Handlers."""
+
 from __future__ import annotations
 
 import abc
 import inspect
-import typing as t
+from collections.abc import Iterable
+from typing import Any, Dict, Generator, Generic, Optional, Sequence, Tuple, Type, Union, cast
 
 import marshmallow as ma
 from asgi_tools.response import parse_response
+from marshmallow import ValidationError
 from muffin import Request
 from muffin.handler import Handler, HandlerMeta
 from muffin.typing import JSONType
@@ -14,74 +17,11 @@ from muffin.typing import JSONType
 from muffin_rest import LIMIT_PARAM, OFFSET_PARAM, openapi
 from muffin_rest.api import API
 from muffin_rest.errors import APIError
-from muffin_rest.filters import Filter, Filters
-from muffin_rest.sorting import Sort, Sorting
+from muffin_rest.filters import Filter
+from muffin_rest.sorting import Sort
 
-T = t.TypeVar("T")
-
-
-class RESTOptions:
-    """Handler Options."""
-
-    name: t.Optional[str] = None
-    name_id: str = "id"
-
-    # limit: Paginate results (set to None for disable pagination)
-    limit: int = 0
-    limit_max: int = 0
-
-    # Base class for filters
-    filters: Filters
-    filters_cls: t.Type[Filters] = Filters
-
-    # Base class for sorting
-    sorting: Sorting
-    sorting_cls: t.Type[Sorting] = Sorting
-
-    # Auto generation for schemas
-    Schema: t.Type[ma.Schema]
-    schema_base: t.Type[ma.Schema] = ma.Schema
-    schema_fields: t.Dict = {}
-    schema_meta: t.Dict = {}
-    schema_unknown: str = ma.EXCLUDE
-
-    base_property: str = "name"
-
-    def __init__(self, cls):
-        """Inherit meta options."""
-        for base in reversed(cls.mro()):
-            if hasattr(base, "Meta"):
-                for k, v in base.Meta.__dict__.items():
-                    if not k.startswith("_"):
-                        setattr(self, k, v)
-
-        if getattr(self, self.base_property, None) is not None:
-            self.setup(cls)
-
-    def setup(self, cls):
-        """Setup the options."""
-        if not self.Schema:
-            name = self.name or "Unknown"
-            self.Schema = type(
-                name.title() + "Schema",
-                (self.schema_base,),
-                dict(self.schema_fields, Meta=self.setup_schema_meta(cls)),
-            )
-
-        if not self.limit_max:
-            self.limit_max = self.limit
-
-    def setup_schema_meta(self, _):
-        """Generate meta for schemas."""
-        return type(
-            "Meta",
-            (object,),
-            dict({"unknown": self.schema_unknown}, **self.schema_meta),
-        )
-
-    def __repr__(self):
-        """Represent self as a string."""
-        return f"<Options {self.name}>"
+from .options import RESTOptions
+from .types import TVResource
 
 
 class RESTHandlerMeta(HandlerMeta):
@@ -99,30 +39,29 @@ class RESTHandlerMeta(HandlerMeta):
         return kls
 
 
-class RESTBase(Handler, metaclass=RESTHandlerMeta):
+class RESTBase(Generic[TVResource], Handler, metaclass=RESTHandlerMeta):
 
     """Load/save resources."""
 
-    if t.TYPE_CHECKING:
-        auth: t.Any
-        collection: t.Any
-        resource: t.Any
+    auth: Any
+    collection: Any
+    resource: Any
 
     meta: RESTOptions
-    meta_class: t.Type[RESTOptions] = RESTOptions
-    _api: t.Optional[API] = None
+    meta_class: Type[RESTOptions] = RESTOptions
+    _api: Optional[API] = None
 
     class Meta:
         """Tune the handler."""
 
         # Resource filters
-        filters: t.Sequence[t.Union[str, t.Tuple[str, str], Filter]] = ()
+        filters: Sequence[Union[str, Tuple[str, str], Filter]] = ()
 
         # Define allowed resource sorting params
-        sorting: t.Sequence[t.Union[str, t.Tuple[str, t.Dict], Sort]] = ()
+        sorting: Sequence[Union[str, Tuple[str, Dict], Sort]] = ()
 
         # Serialize/Deserialize Schema class
-        Schema: t.Optional[t.Type[ma.Schema]] = None
+        Schema: Optional[Type[ma.Schema]] = None
 
     @classmethod
     def __route__(cls, router, *paths, **params):
@@ -147,15 +86,18 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
         return cls
 
     async def __call__(
-        self, request: Request, *, __meth__: str = None, **options
-    ) -> t.Any:
+        self, request: Request, *, __meth__: Optional[str] = None, **options
+    ) -> Any:
         """Dispatch the given request by HTTP method."""
         method = getattr(self, __meth__ or request.method.lower())
         self.auth = await self.authorize(request)
         self.collection = await self.prepare_collection(request)
         resource = await self.prepare_resource(request)
         if resource or request.method != "GET":
-            return await method(request, resource=resource)
+            try:
+                return await method(request, resource=resource)
+            except ValidationError as exc:
+                raise APIError.BAD_REQUEST("Invalid data", errors=exc.messages)
 
         meta = self.meta
 
@@ -182,6 +124,7 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
                 headers = self.paginate_prepare_headers(limit, offset, total)
 
         response = await method(request, resource=resource)
+
         if headers:
             response = parse_response(response)
             response.headers.update(headers)
@@ -195,7 +138,7 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
             raise Exception("The handler is not routed by any API")  # TODO
         return self._api
 
-    async def authorize(self, request: Request):
+    async def authorize(self, request: Request) -> Any:
         """Default authorization method. Proxy auth to self.api."""
         auth = await self.api.authorize(request)
         if not auth:
@@ -205,11 +148,11 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
     # Prepare data
     # ------------
     @abc.abstractmethod
-    async def prepare_collection(self, request: Request) -> t.Any:
+    async def prepare_collection(self, request: Request) -> Any:
         """Prepare a collection of resources. Create queryset, db cursor and etc."""
         raise NotImplementedError
 
-    async def prepare_resource(self, request: Request) -> t.Any:
+    async def prepare_resource(self, request: Request) -> Any:
         """Load a resource."""
         return request["path_params"].get(self.meta.name_id)
 
@@ -219,7 +162,7 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
         """Prepare pagination headers."""
         return {"x-total": total, "x-limit": limit, "x-offset": offset}
 
-    def paginate_prepare_params(self, request: Request) -> t.Tuple[int, int]:
+    def paginate_prepare_params(self, request: Request) -> Tuple[int, int]:
         """Prepare pagination params."""
         meta = self.meta
         query = request.url.query
@@ -232,19 +175,19 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
     @abc.abstractmethod
     async def paginate(
         self, request: Request, *, limit: int = 0, offset: int = 0
-    ) -> t.Tuple[t.Any, int]:
+    ) -> Tuple[Any, int]:
         """Paginate the results."""
         raise NotImplementedError
 
     # Manage data
     # -----------
     @abc.abstractmethod
-    async def save(self, request: Request, resource: T) -> T:
+    async def save(self, request: Request, resource: TVResource) -> TVResource:
         """Save the given resource."""
-        raise NotImplementedError
+        return resource
 
     @abc.abstractmethod
-    async def remove(self, request: Request, *, resource: t.Any = None):
+    async def remove(self, request: Request, resource):
         """Remove the given resource."""
         raise NotImplementedError
 
@@ -266,56 +209,67 @@ class RESTBase(Handler, metaclass=RESTHandlerMeta):
         except (ValueError, TypeError) as exc:
             raise APIError.BAD_REQUEST(str(exc))
 
-    async def load(self, request: Request, resource: T = None) -> t.Any:
+    async def load(
+        self, request: Request, resource: Optional[TVResource] = None
+    ) -> Any:
         """Load data from request and create/update a resource."""
         data = await self.parse(request)
         schema = await self.get_schema(request, resource=resource)
         if not schema:
             return data
 
-        try:
-            resource = schema.load(data, partial=resource is not None, many=isinstance(data, list))  # type: ignore # noqa
-        except ma.ValidationError as exc:
-            raise APIError.BAD_REQUEST("Invalid data", errors=exc.messages)
+        return schema.load(
+            data, partial=resource is not None, many=isinstance(data, list)
+        )  # noqa
 
-        return resource
-
-    async def dump(self, request: Request, response: t.Any, *, many=...) -> JSONType:
+    async def dump(
+        self,
+        request: Request,
+        data: Optional[Iterable] = None,
+        resource: Optional[TVResource] = None,
+        **dump_schema_opts,
+    ) -> JSONType:
         """Serialize the given response."""
-        schema = await self.get_schema(request)
-        if many is ...:
-            many = isinstance(response, t.Sequence)
+        schema = await self.get_schema(request, resource=resource)
+        if schema:
+            return schema.dump(
+                resource if resource is not None else data, **dump_schema_opts
+            )
 
-        return schema.dump(response, many=many) if schema else response
+        return cast(JSONType, data)
 
-    async def get(self, request, *, resource=None) -> JSONType:
+    async def get(self, request: Request, *, resource=None) -> JSONType:
         """Get a resource or a collection of resources.
 
         Specify a path param to load a resource.
         """
         if resource is not None and resource != "":
-            return await self.dump(request, resource)
+            return await self.dump(request, resource=resource)
 
-        return await self.dump(request, self.collection, many=True)
+        return await self.dump(request, data=self.collection, many=True)
 
-    async def post(self, request, *, resource=None) -> JSONType:
+    async def post(self, request: Request, *, resource=None) -> JSONType:
         """Create a resource.
 
         The method accepts a single resource's data or a list of resources to create.
         """
-        resource = await self.load(request, resource)
-        for res in resource if isinstance(resource, list) else [resource]:
-            await self.save(request, res)
-        return await self.dump(request, resource, many=isinstance(resource, list))
+        data = await self.load(request, resource)
+        if isinstance(data, list):
+            return await self.dump(
+                request, data=[await self.save(request, res) for res in data], many=True
+            )
 
-    async def put(self, request, *, resource=None) -> JSONType:
+        res = await self.save(request, data)
+        return await self.dump(request, resource=res)
+
+    async def put(self, request: Request, *, resource=None) -> JSONType:
         """Update a resource."""
         if resource is None:
             raise APIError.NOT_FOUND()
 
         return await self.post(request, resource=resource)
 
-    async def delete(self, request, *, resource=None):
+    async def delete(self, request: Request, *, resource: TVResource | None = None):
         """Delete a resource."""
         if resource is None:
             raise APIError.NOT_FOUND()
@@ -330,8 +284,8 @@ class RESTHandler(RESTBase, openapi.OpenAPIMixin):
 
 
 def to_sort(
-    sort_params: t.Sequence[str],
-) -> t.Generator[t.Tuple[str, bool], None, None]:
+    sort_params: Sequence[str],
+) -> Generator[Tuple[str, bool], None, None]:
     """Generate sort params."""
     for name in sort_params:
         n, desc = name.strip("-"), name.startswith("-")
