@@ -1,12 +1,12 @@
 """Mongo DB support."""
 
-import typing as t
+from typing import List, Optional, Tuple, Type
 
 import bson
 import marshmallow as ma
-import muffin
 from bson.errors import InvalidId
 from motor import motor_asyncio as motor
+from muffin import Request
 
 from muffin_rest.errors import APIError
 from muffin_rest.handler import RESTHandler, RESTOptions
@@ -15,27 +15,29 @@ from muffin_rest.mongo.schema import MongoSchema
 from muffin_rest.mongo.sorting import MongoSorting
 from muffin_rest.mongo.utils import MongoChain
 
+from .types import TVResource
+
 
 class MongoRESTOptions(RESTOptions):
     """Support Mongo DB."""
 
-    filters_cls: t.Type[MongoFilters] = MongoFilters
-    sorting_cls: t.Type[MongoSorting] = MongoSorting
-    schema_base: t.Type[MongoSchema] = MongoSchema
+    filters_cls: Type[MongoFilters] = MongoFilters
+    sorting_cls: Type[MongoSorting] = MongoSorting
+    schema_base: Type[MongoSchema] = MongoSchema
 
-    aggregate: t.Optional[t.List] = None  # Support aggregation. Set to pipeline.
+    aggregate: Optional[List] = None  # Support aggregation. Set to pipeline.
     collection_id: str = "_id"
-    collection: t.Optional[motor.AsyncIOMotorCollection] = None
+    collection: motor.AsyncIOMotorCollection
 
     base_property: str = "collection"
 
-    if t.TYPE_CHECKING:
-        Schema: t.Type[MongoSchema]
+    Schema: Type[MongoSchema]
 
     def setup(self, cls):
         """Prepare meta options."""
         if self.collection is None:
             raise RuntimeError("MongoResthandler.Meta.collection is required")
+        self.name = getattr(self, "name", self.collection.name.lower())
         self.name = self.name or self.collection.name.lower()
         super().setup(cls)
 
@@ -44,15 +46,15 @@ class MongoRESTHandler(RESTHandler):
     """Support Mongo DB."""
 
     meta: MongoRESTOptions
-    meta_class: t.Type[MongoRESTOptions] = MongoRESTOptions
+    meta_class: Type[MongoRESTOptions] = MongoRESTOptions
 
-    async def prepare_collection(self, _: muffin.Request) -> MongoChain:
+    async def prepare_collection(self, _: Request) -> MongoChain:
         """Initialize Peeewee QuerySet for a binded to the resource model."""
         return MongoChain(self.meta.collection)
 
     async def paginate(
-        self, _: muffin.Request, *, limit: int = 0, offset: int = 0
-    ) -> t.Tuple[motor.AsyncIOMotorCursor, int]:
+        self, _: Request, *, limit: int = 0, offset: int = 0
+    ) -> Tuple[motor.AsyncIOMotorCursor, int]:
         """Paginate collection."""
         if self.meta.aggregate:
             pipeline_all = self.meta.aggregate + [{"$skip": offset}, {"$limit": limit}]
@@ -67,15 +69,15 @@ class MongoRESTHandler(RESTHandler):
         total = await self.collection.count()
         return self.collection.skip(offset).limit(limit), total
 
-    async def get(self, request, *, resource=None):
+    async def get(self, request, *, resource: Optional[TVResource] = None):
         """Get resource or collection of resources."""
         if resource is not None and resource != "":
-            return await self.dump(request, resource, many=False)
+            return await self.dump(request, resource=resource)
 
         docs = await self.collection.to_list(None)
-        return await self.dump(request, docs, many=True)
+        return await self.dump(request, data=docs, many=True)
 
-    async def prepare_resource(self, request: muffin.Request) -> t.Optional[dict]:
+    async def prepare_resource(self, request: Request) -> Optional[TVResource]:
         """Load a resource."""
         pk = request["path_params"].get(self.meta.name_id)
         if not pk:
@@ -89,7 +91,7 @@ class MongoRESTHandler(RESTHandler):
             raise APIError.NOT_FOUND() from exc
 
     async def get_schema(
-        self, request: muffin.Request, resource=None, **_
+        self, request: Request, resource: Optional[TVResource] = None, **_
     ) -> ma.Schema:
         """Initialize marshmallow schema for serialization/deserialization."""
         return self.meta.Schema(
@@ -98,22 +100,24 @@ class MongoRESTHandler(RESTHandler):
             exclude=request.url.query.get("schema_exclude", ()),
         )
 
-    async def save(self, _: muffin.Request, resource: t.Dict) -> t.Dict:  # type: ignore
+    async def save(self, _: Request, resource: TVResource) -> TVResource:
         """Save the given resource."""
-        if resource.get(self.meta.collection_id):
+        meta = self.meta
+        if resource.get(meta.collection_id):
             await self.collection.replace_one(
-                {self.meta.collection_id: resource[self.meta.collection_id]}, resource
+                {meta.collection_id: resource[meta.collection_id]}, resource
             )
 
         else:
-            res = await self.meta.collection.insert_one(resource)  # type: ignore
-            resource[self.meta.collection_id] = res.inserted_id
+            res = await meta.collection.insert_one(resource)
+            resource[meta.collection_id] = res.inserted_id
 
         return resource
 
-    async def remove(self, request: muffin.Request, *, resource: dict = None):
+    async def remove(self, request: Request, resource: Optional[TVResource] = None):
         """Remove the given resource(s)."""
-        oids = [resource[self.meta.collection_id]] if resource else await request.data()
+        meta = self.meta
+        oids = [resource[meta.collection_id]] if resource else await request.data()
         if not oids:
             raise APIError.NOT_FOUND()
 
@@ -121,8 +125,6 @@ class MongoRESTHandler(RESTHandler):
             raise APIError.BAD_REQUEST()
 
         oids = [bson.ObjectId(idx) for idx in oids]
-        await self.meta.collection.delete_many(  # type: ignore
-            {self.meta.collection_id: {"$in": oids}}
-        )
+        await meta.collection.delete_many({meta.collection_id: {"$in": oids}})
 
     delete = remove  # noqa
