@@ -1,21 +1,21 @@
 """Support sorting for Peewee ORM."""
 
-import typing as t
+from typing import TypeVar, Union, cast
 
 from peewee import Field, Query
 
 from ..sorting import Sort, Sorting
-
-
-TCOLLECTION = t.TypeVar('TCOLLECTION', bound=Query)
+from .types import TVCollection
 
 
 class PWSort(Sort):
     """Sorter for Peewee."""
 
-    async def apply(self, collection: TCOLLECTION, desc: bool = False, **_) -> TCOLLECTION:
+    async def apply(
+        self, collection: TVCollection, desc: bool = False, **_
+    ) -> TVCollection:
         """Sort the collection."""
-        return collection.order_by_extend(self.field if not desc else self.field.desc())  # type: ignore
+        return collection.order_by_extend(self.field if not desc else self.field.desc())
 
 
 class PWSorting(Sorting):
@@ -23,33 +23,33 @@ class PWSorting(Sorting):
 
     MUTATE_CLASS = PWSort
 
-    def convert(self, obj: t.Union[str, Field, PWSort], **meta):
+    def convert(self, obj: Union[str, Field, PWSort], **meta):
         """Prepare sorters."""
         from . import PWRESTHandler
 
         if isinstance(obj, PWSort):
             return obj
 
-        handler = t.cast(PWRESTHandler, self.handler)
+        handler = cast(PWRESTHandler, self.handler)
 
         if isinstance(obj, Field):
             name, field = obj.name, obj
 
         else:
             name = obj
-            field = meta.get('field', handler.meta.model._meta.fields.get(name))
+            field = meta.get("field", handler.meta.model._meta.fields.get(name))
 
         if field:
             sort = self.MUTATE_CLASS(name, field=field, **meta)
-            if sort.meta.get('default'):
+            if sort.meta.get("default"):
                 self.default.append(sort)
 
             return sort
 
-    def sort_default(self, collection: TCOLLECTION) -> TCOLLECTION:
+    def sort_default(self, collection: TVCollection) -> TVCollection:
         """Sort collection by default."""
         sorting = [
-            sort.field.desc() if sort.meta['default'] == 'desc' else sort.field
+            sort.field.desc() if sort.meta["default"] == "desc" else sort.field
             for sort in self.default
         ]
-        return collection.order_by(*sorting)  # type: ignore
+        return collection.order_by(*sorting)
