@@ -1,20 +1,20 @@
 """Implement sorting."""
 
-import typing as t
+from typing import Any, Generator, List, Mapping, Sequence, Tuple, cast
 
 from muffin import Request
 from muffin.handler import Handler
 
-from .utils import Mutate, Mutator, TCOLLECTION
+from .types import TVCollection
+from .utils import Mutate, Mutator
 
-
-SORT_PARAM = 'sort'
+SORT_PARAM = "sort"
 
 
 class Sort(Mutate):
     """Sort a collection."""
 
-    async def apply(self, collection, desc: bool = False, **_) -> t.Any:
+    async def apply(self, collection, desc: bool = False, **_) -> Any:
         """Sort the collection."""
         return sorted(collection, key=lambda obj: getattr(obj, self.name), reverse=desc)
 
@@ -24,18 +24,20 @@ class Sorting(Mutator):
     """Build sorters for handlers."""
 
     MUTATE_CLASS = Sort
-    mutations: t.Dict[str, Sort]  # type: ignore
+    mutations: Mapping[str, Sort]
 
-    def __init__(self, handler: Handler, params: t.Sequence):
+    def __init__(self, handler: Handler, params: Sequence):
         """Initialize the sorting."""
-        self.default: t.List[Sort] = []
+        self.default: List[Sort] = []
         super(Sorting, self).__init__(handler, params)
 
-    async def apply(self, request: Request, collection: TCOLLECTION, **_) -> TCOLLECTION:
+    async def apply(
+        self, request: Request, collection: TVCollection, **_
+    ) -> TVCollection:
         """Sort the given collection."""
         data = request.url.query.get(SORT_PARAM)
         if data:
-            for name, desc in to_sort(data.split(',')):
+            for name, desc in to_sort(data.split(",")):
                 if name in self.mutations:
                     collection = await self.mutations[name].apply(collection, desc)
 
@@ -46,29 +48,34 @@ class Sorting(Mutator):
 
     def convert(self, obj, **meta) -> Sort:
         """Prepare sorters."""
-        sort: Sort = super(Sorting, self).convert(obj, **meta)  # type: ignore
-        if sort.meta.get('default'):
+        sort = cast(Sort, super(Sorting, self).convert(obj, **meta))
+        if sort.meta.get("default"):
             self.default.append(sort)
         return sort
 
-    def sort_default(self, collection: TCOLLECTION) -> TCOLLECTION:
+    def sort_default(self, collection: TVCollection) -> TVCollection:
         """Sort by default."""
-        return sorted(collection)  # type: ignore
+        return cast(TVCollection, sorted(collection))
 
     @property
     def openapi(self):
         """Prepare OpenAPI params."""
         sorting = list(self.mutations)
         return {
-            'name': SORT_PARAM, 'in': 'query', 'style': 'form', 'explode': False,
-            'schema': {'type': 'array', 'items': {'type': 'string', 'enum': sorting}},
-            'description': ",".join(sorting),
+            "name": SORT_PARAM,
+            "in": "query",
+            "style": "form",
+            "explode": False,
+            "schema": {"type": "array", "items": {"type": "string", "enum": sorting}},
+            "description": ",".join(sorting),
         }
 
 
-def to_sort(sort_params: t.Sequence[str]) -> t.Generator[t.Tuple[str, bool], None, None]:
+def to_sort(
+    sort_params: Sequence[str],
+) -> Generator[Tuple[str, bool], None, None]:
     """Generate sort params."""
     for name in sort_params:
-        n, desc = name.strip('-'), name.startswith('-')
+        n, desc = name.strip("-"), name.startswith("-")
         if n:
             yield n, desc
