@@ -1,14 +1,14 @@
 """SQLAlchemy Core support."""
 
-from __future__ import annotations  # py37
+from __future__ import annotations
 
-import typing as t
+from typing import Optional, Tuple, Type, cast  # py37
 
 import marshmallow as ma
-import muffin
 import sqlalchemy as sa
 from marshmallow_sqlalchemy import ModelConverter
 from marshmallow_sqlalchemy import SQLAlchemyAutoSchema as BaseSQLAlchemyAutoSchema
+from muffin import Request
 from muffin.typing import JSONType
 from muffin_databases import Plugin as DB
 
@@ -17,6 +17,8 @@ from muffin_rest.handler import RESTHandler, RESTOptions
 from muffin_rest.sqlalchemy.filters import SAFilters
 from muffin_rest.sqlalchemy.sorting import SASorting
 
+from .types import TVResource
+
 # XXX: Monkey patch ModelConverter
 ModelConverter._get_field_name = lambda _, prop_or_column: str(prop_or_column.key)  # type: ignore
 
@@ -64,15 +66,15 @@ class SQLAlchemyAutoSchema(BaseSQLAlchemyAutoSchema):
 class SARESTOptions(RESTOptions):
     """Support SQLAlchemy Core."""
 
-    filters_cls: t.Type[SAFilters] = SAFilters
-    sorting_cls: t.Type[SASorting] = SASorting
+    filters_cls: Type[SAFilters] = SAFilters
+    sorting_cls: Type[SASorting] = SASorting
 
     # Schema auto generation params
-    Schema: t.Type[SQLAlchemyAutoSchema]
-    schema_base: t.Type[SQLAlchemyAutoSchema] = SQLAlchemyAutoSchema
+    Schema: Type[SQLAlchemyAutoSchema]
+    schema_base: Type[SQLAlchemyAutoSchema] = SQLAlchemyAutoSchema
 
     table: sa.Table
-    table_pk: t.Optional[sa.Column] = None
+    table_pk: Optional[sa.Column] = None
     database: DB
 
     base_property = "table"
@@ -99,7 +101,7 @@ class SARESTOptions(RESTOptions):
                     "include_fk": True,
                     "dump_only": (self.name_id,),
                 },
-                **self.schema_meta
+                **self.schema_meta,
             ),
         )
 
@@ -108,29 +110,31 @@ class SARESTHandler(RESTHandler):
     """Support SQLAlchemy Core."""
 
     meta: SARESTOptions
-    meta_class: t.Type[SARESTOptions] = SARESTOptions
+    meta_class: Type[SARESTOptions] = SARESTOptions
 
-    async def prepare_collection(self, _: muffin.Request) -> sa.sql.Select:
+    async def prepare_collection(self, _: Request) -> sa.sql.Select:
         """Initialize Peeewee QuerySet for a binded to the resource model."""
         return self.meta.table.select()
 
     async def paginate(
-        self, _: muffin.Request, *, limit: int = 0, offset: int = 0
-    ) -> t.Tuple[sa.sql.Select, int]:
+        self, _: Request, *, limit: int = 0, offset: int = 0
+    ) -> Tuple[sa.sql.Select, int]:
         """Paginate the collection."""
-        qs = sa.select([sa.func.count()]).select_from(self.collection.order_by(None))
+        qs = sa.select([sa.func.count()]).select_from(
+            self.collection.order_by(None).subquery()
+        )
         total = await self.meta.database.fetch_val(qs)
         return self.collection.offset(offset).limit(limit), total
 
-    async def get(self, request, *, resource=None) -> JSONType:
+    async def get(self, request, *, resource: Optional[TVResource] = None) -> JSONType:
         """Get resource or collection of resources."""
         if resource is not None and resource != "":
-            return await self.dump(request, resource, many=False)
+            return await self.dump(request, resource=resource)
 
         rows = await self.meta.database.fetch_all(self.collection)
-        return await self.dump(request, rows, many=True)
+        return await self.dump(request, data=rows, many=True)
 
-    async def prepare_resource(self, request: muffin.Request) -> t.Optional[dict]:
+    async def prepare_resource(self, request: Request) -> Optional[TVResource]:
         """Load a resource."""
         pk = request["path_params"].get(self.meta.name_id)
         if not pk:
@@ -140,10 +144,10 @@ class SARESTHandler(RESTHandler):
         resource = await self.meta.database.fetch_one(qs)
         if resource is None:
             raise APIError.NOT_FOUND("Resource not found")
-        return dict(resource)
+        return cast(TVResource, dict(resource))
 
     async def get_schema(
-        self, request: muffin.Request, *, resource=None, **_
+        self, request: Request, *, resource: Optional[TVResource] = None, **_
     ) -> ma.Schema:
         """Initialize marshmallow schema for serialization/deserialization."""
         return self.meta.Schema(
@@ -152,9 +156,9 @@ class SARESTHandler(RESTHandler):
             exclude=request.url.query.get("schema_exclude", ()),
         )
 
-    async def save(self, _: muffin.Request, resource: t.Dict) -> t.Dict:  # type: ignore
+    async def save(self, _: Request, resource: TVResource) -> TVResource:
         """Save the given resource."""
-        table_pk = t.cast(sa.Column, self.meta.table_pk)
+        table_pk = cast(sa.Column, self.meta.table_pk)
         if resource.get(table_pk.name):
             update = self.meta.table.update().where(table_pk == resource[table_pk.name])
             await self.meta.database.execute(update, resource)
@@ -165,9 +169,9 @@ class SARESTHandler(RESTHandler):
 
         return resource
 
-    async def remove(self, request: muffin.Request, *, resource: dict = None):
+    async def remove(self, request: Request, resource: Optional[TVResource] = None):
         """Remove the given resource."""
-        table_pk = t.cast(sa.Column, self.meta.table_pk)
+        table_pk = cast(sa.Column, self.meta.table_pk)
         pks = [resource[table_pk.name]] if resource else await request.data()
         if not pks:
             raise APIError.NOT_FOUND()
